diff src/share/vm/memory/metaspace.hpp @ 12226:7944aba7ba41

8015107: NPG: Use consistent naming for metaspace concepts Reviewed-by: coleenp, mgerdin, hseigel
author ehelin
date Mon, 12 Aug 2013 17:37:02 +0200
parents 1a8fb39bdbc4
children d6c266999345
line wrap: on
line diff
--- a/src/share/vm/memory/metaspace.hpp	Fri Sep 06 11:11:19 2013 -0700
+++ b/src/share/vm/memory/metaspace.hpp	Mon Aug 12 17:37:02 2013 +0200
@@ -213,9 +213,9 @@
 
   void iterate(AllocRecordClosure *closure);
 
   // Return TRUE only if UseCompressedKlassPointers is True and DumpSharedSpaces is False.
   static bool using_class_space() {
-    return NOT_LP64(false) LP64_ONLY(UseCompressedKlassPointers && !DumpSharedSpaces);
+    return NOT_LP64(false) LP64_ONLY(UseCompressedClassPointers && !DumpSharedSpaces);
   }
 
 };
@@ -213,9 +213,9 @@
   void iterate(AllocRecordClosure *closure);
 
-  // Return TRUE only if UseCompressedKlassPointers is True and DumpSharedSpaces is False.
+  // Return TRUE only if UseCompressedClassPointers is True and DumpSharedSpaces is False.
   static bool using_class_space() {